@@ -22,9 +22,13 @@ from copy import copy, deepcopy
 import trio
 
 from IrcBot import utils
+from IrcBot.message import Message, ReplyIntent
 from IrcBot.sqlitedb import DB
 from IrcBot.utils import debug, log, logger
 
+Message = Message
+ReplyIntent = ReplyIntent
+
 BUFFSIZE = 2048
 MAX_MESSAGE_LEN = 410
 
@@ -196,34 +200,6 @@ class persistentData(object):
         self._queue = []
 
 
-class Message(object):
-    def __init__(self, channel="", sender_nick="", message="", is_private=False):
-        """Message.
-
-        :param channel: Channel from/to which the message is sent or user/nick if private
-        :param sender_nick: Whoever's nick the message came from. Only for received messages. Aliases for this are nick.
-        :param message:str text of the message. Aliases: str, text, txt. For outgoing messages you can also set this to a Color object.
-        :param is_private: If True the message came from a user
-        """
-        self.channel = channel.strip()
-        self.sender_nick = sender_nick.strip()
-        self.nick = sender_nick.strip()
-        self.message = message.strip()
-        self.txt = self.text = self.message
-        self.is_private = is_private
-
-
-class ReplyIntent(object):
-    def __init__(self, message, func):
-        """__init__.
-
-        :param message: Message to send. You can use a message object if you want to change channel or make it a pm.
-        :param func: Function to call passing the received full message string that the user will reply with. This is useful for building dialogs. This function must either return None, a message to send back (str or IrcBot.Message) or another ReplyIntent. It must receive one argument.
-        """
-        self.func = func
-        self.message = message
-
-
 class IrcBot(object):
     """IrcBot."""
 
@@ -501,7 +477,6 @@ class IrcBot(object):
         :param channel: str. Channel name. Include the '#', eg. "#lobby"
         """
         log("Joining", channel)
-        self.channels.append(channel)
         await self.s.send_all(("JOIN " + channel + " \r\n").encode())  # chanel
 
     async def list_channels(self):
@@ -531,6 +506,8 @@ class IrcBot(object):
         """
         if channel is None:
             channel = self.channels
+
+        log(">>>>>>>>>>>>>>", message)
         if type(channel) == list and type(message) != Message:
             for chan in channel:
                 await self._send_message(message, chan)
@@ -547,10 +524,8 @@ class IrcBot(object):
         elif type(message) == Color:
             await self._send_message(message.str, channel)
         elif type(message) == list:
-            raw_msg = ""
             for msg in message:
-                raw_msg += str("PRIVMSG " + channel) + " :" + msg + " \r\n"
-            await self._enqueue_message(raw_msg)
+                await self._send_message(msg, channel)
         elif type(message) == Message:
             await self._send_message(message.message, message.channel)
 
@@ -603,11 +578,7 @@ class IrcBot(object):
         async with trio.open_nursery() as nursery:
             async with self.send_message_channel, self.send_db_operation_channel:
                 async for data in s:
-                    try:
-                        data = data.decode("utf-8")
-                    except UnicodeDecodeError:
-                        log("Decode error")
-                        continue
+                    data = data.decode("utf-8")
                     debug(
                         "DECODED DATA FROM SERVER: \n", 40 * "-", "\n", data, 40 * "-", "\n"
                     )
@@ -751,11 +722,14 @@ class IrcBot(object):
             return
         debug("processing -> ", data)
         try:
-            #TODO use IRC_P instead of all this crap
+            # TODO clear this mess 
+            # This is for replying to users's ping requests
             if (
                 data.find("PING") != -1
                 and len(data.split(":")) >= 3
                 and "PING" in data.split(":")[2]
+                and message['type'] == 'privmsg'
+                and message['channel'] == self.nick
             ):
                 msg = str("PONG " + data.split(":")[1].split("!~")[0] + "\r\n")
                 debug("ponging: ", msg)
@@ -808,11 +782,6 @@ class IrcBot(object):
                 msg = re.sub(r"\003\d\d(?:,\d\d)?", "", msg)
                 debug(f"PARSED MESSAGE: {msg}")
 
-                if channel not in self.channels and channel.startswith("#"):
-                    debug(f"TRYING TO PART {channel}")
-                    await self._enqueue_message(f"PART {channel}")
-                    return
-
                 if (
                     channel in self.replyIntents
                     and sender_nick in self.replyIntents[channel]
